@@ -15,6 +15,9 @@ angular_cookies               = Resource(library, 'angular-cookies.js',
                                          depends=[angular])
 angular_loader                = Resource(library, 'angular-loader.js',
                                          minified='angular-loader.min.js')
+angular_mobile                = Resource(library, 'angular-mobile.js',
+                                         minified='angular-mobile.min.js',
+                                         depends=[angular])
 angular_mocks                 = Resource(library, 'angular-mocks.js',
                                          depends=[angular])
 angular_resource              = Resource(library, 'angular-resource.js',
